package cn.com.poc.expose.rest.impl;

import cn.com.poc.agent_application.convert.AgentApplicationInfoConvert;
import cn.com.poc.agent_application.convert.BizAgentApplicationPublishConvert;
import cn.com.poc.agent_application.dto.AgentApplicationCreateContinueQuesDto;
import cn.com.poc.agent_application.dto.AgentApplicationInfoSearchDto;
import cn.com.poc.agent_application.dto.BizAgentApplicationPublishDto;
import cn.com.poc.agent_application.entity.BizAgentApplicationPublishEntity;
import cn.com.poc.agent_application.service.BizAgentApplicationPublishService;
import cn.com.poc.common.utils.Assert;
import cn.com.poc.common.utils.UUIDTool;
import cn.com.poc.expose.aggregate.AgentApplicationService;
import cn.com.poc.expose.dto.AgentApplicationDto;
import cn.com.poc.expose.rest.AgentApplicationRest;
import cn.com.yict.framemax.core.exception.BusinessException;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.List;

@Component
public class AgentApplicationRestImpl implements AgentApplicationRest {


    @Resource
    private AgentApplicationService agentApplicationService;

    @Resource
    private BizAgentApplicationPublishService bizAgentApplicationPublishService;

    @Override
    public String createDialogues(String agentId) throws Exception {
        return "DIA_" + UUIDTool.getUUID();
    }

    @Override
    public void callAgentApplication(AgentApplicationDto dto, HttpServletResponse httpServletResponse) throws IOException {
        Assert.notNull(dto, "参数不能为空");
        Assert.notBlank(dto.getInput(), "输入不能为空");
        Assert.notNull(dto.getAgentId(), "应用ID不能为空");
        Assert.notNull(dto.getDialogsId(), "对话ID不能为空");
        try {
            agentApplicationService.callAgentApplication(dto.getAgentId(), dto.getDialogsId(), dto.getInput(), httpServletResponse);
        } catch (Exception e) {
            httpServletResponse.setContentType("text/event-stream");
            PrintWriter writer = httpServletResponse.getWriter();
            writer.write("data: {\"code\":-1,\"message\":\"" + e.getMessage() + "\"} \n\n");
            writer.write("data: [DONE]\n\n");
            writer.flush();
        }
    }

    @Override
    public List<BizAgentApplicationPublishDto> getAgentApplication(AgentApplicationInfoSearchDto dto, HttpServletResponse httpServletResponse) throws Exception {
        return null;
    }

    @Override
    public BizAgentApplicationPublishDto getInfo(String agentId) throws Exception {
        Assert.notBlank(agentId, "应用ID不能为空");
        BizAgentApplicationPublishEntity entity = bizAgentApplicationPublishService.getByAgentId(agentId);
        if (entity == null) {
            throw new BusinessException("应用不存在");
        }
        return BizAgentApplicationPublishConvert.entityToDto(entity);
    }

    @Override
    public List<String> createContinueQuestions(AgentApplicationCreateContinueQuesDto dto) throws Exception {
        cn.com.poc.common.utils.Assert.notNull(dto.getInput(), "input不能为空");
        return agentApplicationService.createContinueQuestions(dto.getInput());
    }
}
